@@ -1802,3 +1802,15 @@ int32_t SPVM__Sys__IO__Constant__O_TEXT(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 }
 
+int32_t SPVM__Sys__IO__Constant__O_ACCMODE(SPVM_ENV* env, SPVM_VALUE* stack) {
+
+#ifdef O_ACCMODE
+  stack[0].ival = O_ACCMODE;
+  return 0;
+#else
+  env->die(env, stack, "O_ACCMODE is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#endif
+
+}
+
